Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/Duet3D/RepRapFirmware.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDavid Crocker <dcrocker@eschertech.com>2018-05-10 15:00:54 +0300
committerDavid Crocker <dcrocker@eschertech.com>2018-05-10 15:00:54 +0300
commit980babc6566191b764cad478bf286703a8cea1dc (patch)
tree47606a4835582bf4c7c7c40506d90a8f80258aa0 /src/Storage/FileWriteBuffer.h
parent71b060436abaaecd9f67d90d6e6581e2f5c8ad90 (diff)
RRF 2.0RC2/1.21RC2 provisional
More improvements to 12864 display support Implemented M144 S1 Merged in chrishamm's changes
Diffstat (limited to 'src/Storage/FileWriteBuffer.h')
-rw-r--r--src/Storage/FileWriteBuffer.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/Storage/FileWriteBuffer.h b/src/Storage/FileWriteBuffer.h
index d5198e8c..be6f19fd 100644
--- a/src/Storage/FileWriteBuffer.h
+++ b/src/Storage/FileWriteBuffer.h
@@ -35,7 +35,8 @@ public:
const size_t BytesLeft() const { return FileWriteBufLen - index; }
size_t Store(const char *data, size_t length); // Stores some data and returns how much could be stored
- void DataTaken() { index = 0; } // Called to indicate that the buffer has been written
+ void DataTaken() { index = 0; } // Called to indicate that the buffer has been written to the SD card
+ void DataStored(size_t numBytes) { index += numBytes; } // Called when more data has been stored directly in the buffer
private:
FileWriteBuffer *next;